@@ -1,10 +1,12 @@
 pub mod app;
 pub mod server;
+pub mod settings;
 pub mod theme;
 pub mod ui;
 pub mod widgets;
 
 pub use app::App;
 pub use server::{ActiveTestInfo, ServerApp};
+pub use settings::{SettingsAction, SettingsState, TuiLoopResult};
 pub use theme::Theme;
 pub use ui::draw;
